==> pangle_flutter-1.8.0.tar.gz: example/lib/page/constant.dart <==
/*
 * Copyright (c) 2021 nullptrX
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

const kAppId = '5153502';
const kSplashId = '887451293';
const kRewardedVideoExpressId = '945940983';
// 600x260
const kBannerExpressId = '945940906';
// 375x284
const kFeedExpressId = '945940981';
// 3x2
// const kInterstitialExpressId = '945940989';
// 1x1
const kInterstitialExpressId = '945940988';
// 新模板渲染插屏
const kFullscreenIdFull = '945999649';
// 全屏视频
const kFullscreenVideoExpressId = '945940986';

==> pangle_flutter-2.0.0.tar.gz: example/lib/page/constant.dart <==
/*
 * Copyright (c) 2021 nullptrX
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

const kAppId = '5001121';
const kSplashId = '888041257';
const kRewardedVideoExpressId = '901121365';
// 600x260
const kBannerExpressId = '901121148';
// 375x284
const kFeedExpressId = '901121253'; // info
// const kFeedExpressId = '901121134'; // video
// 3x2
// const kInterstitialExpressId = '945940989';
// 1x1
const kInterstitialExpressId = '947793385';
// 新模板渲染插屏
const kFullscreenIdFull = '901121375';
// 全屏视频
const kFullscreenVideoExpressId = '901121073';
